@@ -292,6 +292,9 @@ QScrollArea{
             self.Thread1.文件位置 = self.文件位置
             self.Thread1.待插入的文件夹位置 = self.待插入的文件夹位置
             self.Thread1.start()
+        else:
+            print("验证失败")
+            self.textEdit.setPlainText("验证失败")
     # def ture_run(self):
 
 class RunThread(QThread):
